==> codelite_1.0.2759+dfsg.orig.tar.gz: codelite-1.0.2759+dfsg/LiteEditor/taskpanel.h <==
//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////
//
// copyright            : (C) 2008 by Eran Ifrah                            
// file name            : taskpanel.h              
//                                                                          
// -------------------------------------------------------------------------
// A                                                                        
//              _____           _      _     _ _                            
//             /  __ \         | |    | |   (_) |                           
//             | /  \/ ___   __| | ___| |    _| |_ ___                      
//             | |    / _ \ / _  |/ _ \ |   | | __/ _ )                     
//             | \__/\ (_) | (_| |  __/ |___| | ||  __/                     
//              \____/\___/ \__,_|\___\_____/_|\__\___|                     
//                                                                          
//                                                  F i l e                 
//                                                                          
//    This program is free software; you can redistribute it and/or modify  
//    it under the terms of the GNU General Public License as published by  
//    the Free Software Foundation; either version 2 of the License, or     
//    (at your option) any later version.                                   
//                                                                          
//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////

#ifndef __taskpanel__
#define __taskpanel__

#include "findresultstab.h"

class wxToggleButton;


class TaskPanel : public FindResultsTab
{
private:
    wxArrayString m_extensions;
	std::vector<wxToggleButton*> m_task;
    wxChoice *m_scope;
    wxChoice *m_filter;
    
protected:
    void DoSetSearchData();
    
    void OnToggle     (wxCommandEvent  &e);
	void OnSearch     (wxCommandEvent  &e);
    void OnCustomize  (wxCommandEvent  &e);
    void OnSearchUI   (wxUpdateUIEvent &e);
    void OnCustomizeUI(wxUpdateUIEvent &e);
    
    DECLARE_EVENT_TABLE()
	
public:
	TaskPanel(wxWindow* parent, wxWindowID id, const wxString &name);
    ~TaskPanel();
};

#endif // __taskpanel__

==> codelite_1.0.2893+dfsg.orig.tar.gz: codelite-1.0.2893+dfsg/LiteEditor/taskpanel.h <==
//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////
//
// copyright            : (C) 2008 by Eran Ifrah
// file name            : taskpanel.h
//
// -------------------------------------------------------------------------
// A
//              _____           _      _     _ _
//             /  __ \         | |    | |   (_) |
//             | /  \/ ___   __| | ___| |    _| |_ ___
//             | |    / _ \ / _  |/ _ \ |   | | __/ _ )
//             | \__/\ (_) | (_| |  __/ |___| | ||  __/
//              \____/\___/ \__,_|\___\_____/_|\__\___|
//
//                                                  F i l e
//
//    This program is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    (at your option) any later version.
//
//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////

#ifndef __taskpanel__
#define __taskpanel__

#include "findresultstab.h"

class wxToggleButton;


class TaskPanel : public FindResultsTab
{
private:
    wxArrayString m_extensions;
	std::vector<wxToggleButton*> m_task;
    wxChoice *m_scope;
    wxChoice *m_filter;

protected:
    SearchData DoGetSearchData();
    void       OnToggle       (wxCommandEvent  &e);
	void       OnSearch       (wxCommandEvent  &e);
    void       OnCustomize    (wxCommandEvent  &e);
    void       OnSearchUI     (wxUpdateUIEvent &e);
    void       OnCustomizeUI  (wxUpdateUIEvent &e);
	void       OnRepeatOutput (wxCommandEvent  &e);

    DECLARE_EVENT_TABLE()

public:
	TaskPanel(wxWindow* parent, wxWindowID id, const wxString &name);
    ~TaskPanel();
};

#endif // __taskpanel__
